@@ -1,12 +1,40 @@
+"""
+The MIT License (MIT)
+
+Copyright (c) 2022-present jaczerob
+
+Permission is hereby granted, free of charge, to any person obtaining a
+copy of this software and associated documentation files (the "Software"),
+to deal in the Software without restriction, including without limitation
+the rights to use, copy, modify, merge, publish, distribute, sublicense,
+and/or sell copies of the Software, and to permit persons to whom the
+Software is furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
+"""
+
 from abc import abstractmethod, ABC
 from pathlib import Path
 from typing import Optional, Union
+import aiohttp
+import requests
 
 from .models import *
 from .httpclient import BaseHTTPClient, SyncHTTPClient, AsyncHTTPClient, Route
 
 
 class BaseToontownClient(ABC):
+    """Base Toontown Client to provide functionality for users to interact with the Toontown Rewritten API"""
+
     @abstractmethod
     def __init__(self, httpclient: BaseHTTPClient) -> None:
         self.http = httpclient
@@ -40,7 +68,8 @@ class BaseToontownClient(ABC):
         *, 
         username: Optional[str] = None, 
         password: Optional[str] = None,
-        response_token: Optional[str] = None,
+        app_token: Optional[str] = None,
+        auth_token: Optional[str] = None,
         queue_token: Optional[str] = None,
     ) -> Login: 
         """Request to log into Toontown Rewritten's game server
@@ -77,9 +106,13 @@ class BaseToontownClient(ABC):
         """Request News data from the Toontown Rewritten API"""
 
     @abstractmethod
-    def release_notes(self, *, id: Optional[int] = None) -> ReleaseNotes:
+    def release_notes(self, *, id: Optional[int] = None) -> ReleaseNotesList:
         """Request Release Notes data from the Toontown Rewritten API"""
 
+    @abstractmethod
+    def status(self) -> Status:
+        """Request Status data from the Toontown Rewritten API"""
+
     @abstractmethod
     def update(self, path: Union[str, Path]) -> None:
         """Updates or creates the Toontown Rewritten files at the given Path"""
@@ -88,8 +121,8 @@ class BaseToontownClient(ABC):
 class SyncToontownClient(BaseToontownClient):
     """Synchronous client to interact with the Toontown Rewritten API"""
 
-    def __init__(self) -> None:
-        super().__init__(SyncHTTPClient())
+    def __init__(self, *, session: Optional[requests.Session] = None) -> None:
+        super().__init__(SyncHTTPClient(session=session))
 
     def connect(self) -> None:
         self.http.connect()
@@ -97,7 +130,15 @@ class SyncToontownClient(BaseToontownClient):
     def close(self) -> None:
         self.http.close()
 
-    def release_notes(self, *, id: Optional[int] = None) -> ReleaseNotes:
+    def status(self) -> Status:
+        data = self.http.request(Route(
+            'GET',
+            '/status'
+        ))
+
+        return Status(**data)
+
+    def release_notes(self, *, id: Optional[int] = None) -> ReleaseNotesList:
         if id is not None:
             path = f'/releasenotes/{id}'
         else:
@@ -113,7 +154,7 @@ class SyncToontownClient(BaseToontownClient):
         else:
             data = dict(iterable=data)
 
-        return ReleaseNotes(**data)
+        return ReleaseNotesList(**data)
         
     def news(self, *, id: Optional[int] = None, all: Optional[bool] = False) -> NewsList:
         if id is not None:
@@ -219,8 +260,8 @@ class SyncToontownClient(BaseToontownClient):
 class AsyncToontownClient(BaseToontownClient):
     """Asynchronous client to interact with the Toontown Rewritten API"""
 
-    def __init__(self) -> None:
-        super().__init__(AsyncHTTPClient())
+    def __init__(self, *, session: Optional[aiohttp.ClientSession] = None) -> None:
+        super().__init__(AsyncHTTPClient(session=session))
 
     async def connect(self) -> None:
         await self.http.connect()
@@ -228,7 +269,15 @@ class AsyncToontownClient(BaseToontownClient):
     async def close(self) -> None:
         await self.http.close()
 
-    async def release_notes(self, *, id: Optional[int] = None) -> ReleaseNotes:
+    async def status(self) -> Status:
+        data = await self.http.request(Route(
+            'GET',
+            '/status'
+        ))
+
+        return Status(**data)
+
+    async def release_notes(self, *, id: Optional[int] = None) -> ReleaseNotesList:
         if id is not None:
             path = f'/releasenotes/{id}'
         else:
@@ -244,7 +293,7 @@ class AsyncToontownClient(BaseToontownClient):
         else:
             data = dict(iterable=data)
 
-        return ReleaseNotes(**data)
+        return ReleaseNotesList(**data)
         
     async def news(self, *, id: Optional[int] = None, all: Optional[bool] = False) -> NewsList:
         if id is not None:
