@@ -1,3 +1,35 @@
+"""
+The MIT License (MIT)
+
+Copyright (c) 2022-present jaczerob
+
+Permission is hereby granted, free of charge, to any person obtaining a
+copy of this software and associated documentation files (the "Software"),
+to deal in the Software without restriction, including without limitation
+the rights to use, copy, modify, merge, publish, distribute, sublicense,
+and/or sell copies of the Software, and to permit persons to whom the
+Software is furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
+"""
+
+from abc import ABC, abstractmethod
+from multiprocessing.pool import ThreadPool
+from pathlib import Path
+from typing import (
+    Any,
+    Optional,
+    Union
+)
 import asyncio
 import bz2
 import hashlib
@@ -6,16 +38,6 @@ import os
 import platform
 import sys
 import time
-from abc import ABC, abstractmethod
-from multiprocessing.pool import ThreadPool
-from pathlib import Path
-from typing import (
-    Any,
-    Dict,
-    List,
-    Tuple,
-    Union
-)
 
 import aiohttp
 import requests
@@ -48,7 +70,7 @@ CHUNK_SIZE = 10 * 10 * 1024
 
 def get_platform():
     if sys.platform == 'win32' and platform.machine().endswith('64'):
-        return 'win64'
+        return 'win64' # for handling 64 bit files in the patch manifest
     return sys.platform
 
 
@@ -60,14 +82,14 @@ class Route:
         self.url = BASE + path
 
     @property
-    def headers(self) -> Dict[str, Any]:
+    def headers(self) -> dict[str, Any]:
         return LOGIN_HEADERS if self.path == '/login' else BASE_HEADERS
 
 
 class BaseHTTPClient(ABC):
     @abstractmethod
-    def __init__(self) -> None:
-        self._session: Session = None
+    def __init__(self, *, session: Optional[Session] = None) -> None:
+        self._session = session
 
     @abstractmethod
     def connect(self) -> None: ...
@@ -81,35 +103,23 @@ class BaseHTTPClient(ABC):
     @abstractmethod
     def update(self, path: Union[str, Path]) -> None: ...
 
-    def get_outdated_files(self, manifest: Dict[str, Any], path: Path) -> List[Tuple[str, Path]]:
-        files = []
+    def get_outdated_files(self, manifest: dict[str, Any], path: Path) -> list[Tuple[str, Path]]:
         pf = get_platform()
 
-        for file in manifest:
-            if pf not in manifest[file]['only']:
-                continue
-
-            file_path: Path = path / file
-            url = '{0}/{1}'.format(PATCHES, manifest[file]['dl'])
-
-            if not file_path.exists():
-                files.append((url, file_path))
-                logger.info(f'Queuing {file} for download')
-                continue
-
-            hash_alg = hashlib.sha1()
-            hash_alg.update(file_path.open('rb').read())
-
-            if manifest[file]['hash'] != hash_alg.hexdigest():
-                files.append((url, file_path))
-                logger.info(f'Queuing {file} for download')
-
-        return files
+        return [
+            ('{0}/{1}'.format(PATCHES, props['dl']), (path / file))
+            for file, props in manifest.items()
+            if pf not in props['only'] and\
+            (
+                not (path / file).exists() or\
+                props['hash'] != hashlib.sha1((path / file).open('rb').read()).hexdigest()
+            )
+        ]
 
 
 class SyncHTTPClient(BaseHTTPClient):
-    def __init__(self) -> None:
-        self._session: requests.Session = None
+    def __init__(self, *, session: Optional[requests.Session] = None) -> None:
+        self._session: requests.Session = session
         self._is_closed = True
 
     @property
@@ -121,7 +131,9 @@ class SyncHTTPClient(BaseHTTPClient):
         self._is_closed = bool(value)
 
     def connect(self) -> None:
-        self._session = requests.Session()
+        if self._session is None:
+            self._session = requests.Session()
+            
         self._is_closed = False
 
     def close(self) -> None:
@@ -197,11 +209,12 @@ class SyncHTTPClient(BaseHTTPClient):
 
 
 class AsyncHTTPClient(BaseHTTPClient):
-    def __init__(self) -> None:
-        self._session: aiohttp.ClientSession = None
+    def __init__(self, *, session: Optional[aiohttp.ClientSession] = None) -> None:
+        self._session: aiohttp.ClientSession = session
 
     async def connect(self) -> None:
-        self._session = aiohttp.ClientSession(raise_for_status=True)
+        if self._session is None:
+            self._session = aiohttp.ClientSession(raise_for_status=True)
 
     async def close(self) -> None:
         await self._session.close()
