@@ -1,3 +1,28 @@
+"""
+The MIT License (MIT)
+
+Copyright (c) 2022-present jaczerob
+
+Permission is hereby granted, free of charge, to any person obtaining a
+copy of this software and associated documentation files (the "Software"),
+to deal in the Software without restriction, including without limitation
+the rights to use, copy, modify, merge, publish, distribute, sublicense,
+and/or sell copies of the Software, and to permit persons to whom the
+Software is furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
+"""
+
+from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 
@@ -7,7 +32,7 @@ from .base import BaseAPIModel
 __all__ = ['FieldOffice', 'FieldOffices']
 
 
-zone_lookup = {
+ZONE_LOOKUP = {
     '3100': 'Walrus Way',
     '3200': 'Sleet Street',
     '3300': 'Polar Place',
@@ -21,11 +46,12 @@ zone_lookup = {
     '9200': 'Pajama Place',
 }
 
-department_lookup = {
+DEPARTMENT_LOOKUP = {
     's': 'Sellbot'
 }
 
 
+@dataclass
 class FieldOffice:
     """Wrapper class for field office data
     
@@ -58,15 +84,15 @@ class FieldOffice:
     
     def __init__(self, last_updated, zone, *, department, difficulty, annexes, open, expiring) -> None:
         self.last_updated: datetime = last_updated
-        self.street: str = zone_lookup[zone]
-        self.department: str = department_lookup[department]
+        self.street: str = ZONE_LOOKUP[zone]
+        self.department: str = DEPARTMENT_LOOKUP[department]
         self.difficulty: int = difficulty + 1
         self.annexes: int = annexes
         self.open: bool = open
         self.expiring: Optional[datetime] = datetime.fromtimestamp(expiring) if expiring else None
 
 
-class FieldOffices(BaseAPIModel):
+class FieldOffices(BaseAPIModel[FieldOffice]):
     """"Wrapper class for /fieldoffices response
 
     A tuple-like class containing `FieldOffice` objects, sorted by difficulty
